<?php

class AccountForm extends Form
{
	public function __construct()
	{
		global $USER;
		
		if (!isset($USER))
			throw new Exception("User not logged in!");
			
		$submit = new Button("btnSave", "Save Changes");
		$submit->onClick = "return validateAccountForm()";
			
		parent::__construct(
			"Account Settings",
			get_class($this),
			strip_query(full_me()),
			array(
				new TextField("username", "Username", $USER->username),
				new PasswordField("password1", "Password", "{NO-PASSWORD-CHANGE}"),
				new PasswordField("password2", "Confirm Password:", "{NO-PASSWORD-CHANGE}"),
				new TextField("first_name", "First Name", $USER->first_name),
				new TextField("last_name", "Last Name", $USER->last_name),
				new TextField("email", "E-mail Address", $USER->email)
			),
			$submit
		);
		
		$this->getField("username")->validator = new RequiredValidator();
		$this->getField("password1")->validator = new RequiredValidator();
		$this->getField("password2")->validator = new CompareFieldsValidator($this->getField("password1"));
		$this->getField("first_name")->validator = new RequiredValidator();
		$this->getField("last_name")->validator = new RequiredValidator();
		$this->getField("email")->validator = new EmailValidator();
	}
	
	protected function formStart($style)
	{
?>

<script type="text/javascript">
<!--
function setFocusDelayed() {
	global_focus.focus();
}
function validateAccountForm() {
	theform = document.forms['<?php echo get_class($this) ?>'];
	if(theform.elements['username'].value == '') {
		alert("Please enter your desired username");
		global_focus = theform.elements['username'];
		setTimeout('setFocusDelayed()', 100);
		return false;
	}
	if(theform.elements['first_name'].value == '') {
		alert("Please enter your first name");
		global_focus = theform.elements['first_name'];
		setTimeout('setFocusDelayed()', 100);
		return false;
	}
	if(theform.elements['last_name'].value == '') {
		alert("Please enter your last name");
		global_focus = theform.elements['last_name'];
		setTimeout('setFocusDelayed()', 100);
		return false;
	}
	if(theform.elements['email'].value == '') {
		alert("Please enter your e-mail address");
		global_focus = theform.elements['email'];
		setTimeout('setFocusDelayed()', 100);
		return false;
	}
	if(theform.elements['password1'].value == '') {
		alert("Please enter your password");
		global_focus = theform.elements['password1'];
		setTimeout('setFocusDelayed()', 100);
		return false;
	}
	if(theform.elements['password2'].value == '') {
		alert("Please confirm your password");
		global_focus = theform.elements['password2'];
		setTimeout('setFocusDelayed()', 100);
		return false;
	}
	if(theform.elements['password1'].value != theform.elements['password2'].value) {
		alert("The passwords you entered do not match.  Please correct.");
		global_focus = theform.elements['password1'];
		setTimeout('setFocusDelayed()', 100);
		return false;
	}
	return true;
}
-->
</script>
<?php
		parent::formStart($style);
	}

	public function process()
	{
		global $CFG, $USER;
		
		if ($this->isValid())
		{
			// Check that the username is not change (or not already used)
			$userRecord = get_record("users", array("username" => $this->getField("username")->value));
			if ($userRecord) {
				if ($userRecord->id != $USER->id) {
					notify("That username is already taken.  Please try again.");
					return false;
				}
			}
			
			// Make sure we have the user's record
			$userRecord = get_record("users", array("id", $USER->id));
			$userRecord->username = $this->getField("username")->value;
			
			if ($this->getField("password1")->value != "{NO-PASSWORD-CHANGE}")
				$userRecord->password = $this->getField("password1")->encrypted();				

			$userRecord->first_name = $this->getField("first_name")->value;
			$userRecord->last_name = $this->getField("last_name")->value;
			$userRecord->email = $this->getField("email")->value;
			
			if (update_record('users', $userRecord)) {
				notify("Your changes were saved.", "green");
				$USER->username = $this->getField("username")->value;
				$USER->first_name = $this->getField("first_name")->value;
				$USER->last_name = $this->getField("last_name")->value;
				$USER->email = $this->getField("email")->value;
				return true;
			} else {
				notify("Changes not saved.");
				return false;
			}
		}
		return false;
	}
}

?>
