<?php
/**
 * Defines the CryptBlowfish encryption class.
 *
 * @package CryptLib
 */

/**
 * This class implements the Blowfish encryption algorithm.
 * You must supply a 12 or 13 character salt to use during this scheme.
 * 
 * @package CryptLib
 * @version 0.1
 * @author Randy L. Pearson
 */
class CryptBlowfish implements CryptEngine
{
	private $options;
	
	/**
	 * Constructor
	 * 
	 * @param PropertyHolder $options Optional list of properties.  Extracts the 'salt' property.
	 * @return none Throws error if encryption algorithm not available or no 'salt' property.
	 */
	public function __construct(PropertyHolder $options = null)
	{
		if (CRYPT_BLOWFISH != 1) {
			throw new Exception("Blowfish encryption is not available on this system.");			
		}

		if ($options->isValid("salt")) {
			if (strlen($options->salt) != 12 && strlen($options->salt) != 13) {
				throw new Excpetion("Blowfish requires a 12 or 13 character salt.");
			} else {
				$this->options = new PropertyBag(array("salt" => $options->salt));
			}
		} else {
			throw new Exception("Blowfish requires a 12 or 13 character salt.");
		}
	}
	
	/**
	 * Encrypt the string using the Standard DES algorithm.  Uses 'salt' string.
	 * 
	 * @param string $data Data to be encrypted.
	 * @return string The encrypted data.
	 */
	public function encrypt($data)
	{
		if (strlen($this->options->salt) == 12)	
			return crypt($data, "$2a$" . $this->options->salt);
		else
			return crypt($data, "$2$" . $this->options->salt);
	}
	
	/**
	 * Blowfish is a one-way encryption, so throws error always.
	 */
	public function decrypt($data)
	{
		throw new Exception("Blowfish is a one-way encryption.  Cannot decrypt data.");
	}
	
	/**
	 * Changes the current options for the encryption scheme.  Only looks for the 'salt' property.
	 * 
	 * @param PropertyHolder $options The properties to be copied.  Only copies 'salt' if found.
	 * @return none Throws error if 'salt' property is not found or invalid.
	 */
	public function setOptions(PropertyHolder $options)
	{
		if ($options->isValid("salt")) {
			if (strlen($options->salt) != 12 && strlen($optons->salt) != 13) {
				throw new Exception("Blowfish requires a 12 or 13 character salt.");
			}	
		
			if ($this->options->isValid("salt"))
				$this->options->salt = $options->salt;
			else
				$this->options->add("salt", $options->salt);
		} else {
			throw new Exception("Missing 'salt' property in options");
		}
	}
	
	/**
	 * Returns the current options.
	 * 
	 * @return PropertyHolder A list of current properties for the engine.
	 */
	public function getOptions()
	{
		return $this->options;
	}
}

?>
