<?php
/**
 * Defines the CryptEngine interface.
 *
 * @package CryptLib
 */
  
/**
 * Defines an interface to query and create cryptographic engines.
 * 
 * @package CryptLib
 * @version 0.1
 * @author Randy
 */

interface CryptEngine
{
	/**
	 * Encrypts a string and returns the encrypted version.
	 * 
	 * @param string $text The data to be encrypted.
	 * @return string An encrypted form of the string.
	 */
	public function encrypt($text);
	
	/**
	 * Decrypts an encrypted string.
	 * 
	 * @param string $text The data to be decrypted.
	 * @return string The decrypted form of the string.
	 */
	public function decrypt($text);
	
	/**
	 * Sets the options for the encryption scheme.
	 * 
	 * @param PropertyHolder $options Varies depending on the encryption engine.
	 */
	public function setOptions(PropertyHolder $options);
	
	/**
	 * Returns the current options for the encryption scheme.
	 * 
	 * @return PropertyHolder Varies depending on the encryption scheme.
	 */
	public function getOptions();
}

?>
