<?php
/**
 * Defines the CryptFactory encryption class.
 *
 * @package CryptLib
 */

/**
 * Helper class that is used to determine which encryption algorithms are available and creates new CryptEngine objects.
 * 
 * @package CryptLib
 * @version 0.1
 * @author Randy L. Pearson
 */

class CryptFactory
{
	public static function engineNames()
	{
		if (CRYPT_STD_DES == 1)
			$engines[] = "CryptDES";
		
		if (CRYPT_EXT_DES == 1)
			$engines[] = "CryptExtDES";
			
		if (CRYPT_MD5 == 1)
			$engines[] = "CryptMD5";
			
		if (CRYPT_BLOWFISH == 1)
			$engines[] = "CryptBlowfish";
			
		if (function_exists("md5"))
			$engines[] = "CryptNativeMD5";
			
		if (function_exists("sha1"))
			$engines[] = "CryptNativeSHA1";
			
		if (function_exists("mcrypt_list_algorithms")) {
			$engines[] = "CryptMcrypt";
		}
			
		return $engines;
	}
	
	public static function createEngine($engineName, $options = null)
	{
		if (!in_array($engineName, CryptFactory::engineNames()))
			throw new Exception("The cryptographic engine '$engineName' is not available.");
		
		return new $engineName($options);
	}
}

?>
