<?php
/**
 * Defines the CryptNativeMD5 encryption class.
 *
 * @package CryptLib
 */

/**
 * This class implements the MD5 encryption algorithm using the built-in
 * md5() function.
 * 
 * @package CryptLib
 * @version 0.1
 * @author Randy L. Pearson
 */
class CryptNativeMD5 implements CryptEngine
{
	/**
	 * Constructor
	 * 
	 * @param PropertyHolder $options Optional list of properties.  (Not used.)
	 */
	public function __construct(PropertyHolder $options = null)
	{
		if (!function_exists("md5"))	
			throw new Exception("The md5() function is not available on this system.");			
	}
	
	/**
	 * Encrypt the string using the RSA MD5 algorithm.
	 * 
	 * @param string $data Data to be encrypted.
	 * @return string The encrypted data.
	 */
	public function encrypt($data)
	{
		return md5($data);
	}
	
	/**
	 * MD5 is a one-way encryption, so throws error always.
	 */
	public function decrypt($data)
	{
		throw new Exception("MD5 is a one-way encryption.  Cannot decrypt data.");
	}
	
	/**
	 * Changes the current options for the encryption scheme.
	 * 
	 * @param PropertyHolder $options The properties to be copied.
	 * @return none Throws error always.
	 */
	public function setOptions(PropertyHolder $options)
	{
		throw new Exception("CryptNativeMD5 does not support options");
	}
	
	/**
	 * Returns the current options.
	 * 
	 * @return none Throws error since this algorithm has no options.
	 */
	public function getOptions()
	{
		throw new Exception("CryptNativeMD5 has no options");
	}
}

?>
