<?php
/**
 * Defines the CryptNativeSHA1 encryption class.
 *
 * @package CryptLib
 */

/**
 * This class implements the SHA encryption algorithm using the built-in
 * sha1() function.
 * 
 * @package CryptLib
 * @version 0.1
 * @author Randy L. Pearson
 */
class CryptNativeSHA1 implements CryptEngine
{
	/**
	 * Constructor
	 * 
	 * @param PropertyHolder $options Optional list of properties.  (Not used.)
	 */
	public function __construct(PropertyHolder $options = null)
	{
		if (!function_exists("sha1"))	
			throw new Exception("The sha1() function is not available on this system.");			
	}
	
	/**
	 * Encrypt the string using the US SHA1 hashing algorithm.
	 * 
	 * @param string $data Data to be encrypted.
	 * @return string The encrypted data.
	 */
	public function encrypt($data)
	{
		return sha1($data);
	}
	
	/**
	 * SHA1 is a one-way encryption, so throws error always.
	 */
	public function decrypt($data)
	{
		throw new Exception("SHA1 is a one-way encryption.  Cannot decrypt data.");
	}
	
	/**
	 * Changes the current options for the encryption scheme.
	 * 
	 * @param PropertyHolder $options The properties to be copied.
	 * @return none Throws error always.
	 */
	public function setOptions(PropertyHolder $options)
	{
		throw new Exception("CryptNativeSHA1 does not support options");
	}
	
	/**
	 * Returns the current options.
	 * 
	 * @return none Throws error always.
	 */
	public function getOptions()
	{
		throw new Exception("CryptNativeSHA1 has no options");
	}
}

?>
