<?php
/**
 * Defines the Button class.
 * 
 * Changes:
 * 
 * Version 0.3 moved the table cell and row output from this class to the
 * Form class.  This allows forms to hold easily support more than one Button
 * object.
 * 
 * @package FormLib
 * @version 0.3
 */

/**
 * A simple submit button class.
 * 
 * @package FormLib
 * @author Randy L. Pearson
 */

class Button
{
	protected $properties;
	
	/**
	 * Constructor
	 * 
	 * Initializes a button object.
	 * 
	 * @param string $name Name of the button.
	 * @param string $label Text for the button.
	 * @param PropertyHolder $properties Extra properties to attach to button.
	 * @param PropertyHolder $style Style information.
	 */
	public function __construct($name, $label, $style = false)
	{
		$this->properties = new PropertyBag(
			array(
				"name" => $name,
				"label" => $label,
				"style" => false,
				"onClick" => false
				));
			
		if ($style) {
			if ($style instanceof PropertyHolder)
				$this->style = $style;
			else
				throw new Exception("Button constructor error: \$style is of type (".get_class($style).") which does not implement the PropertyHolder interface.");
		}
	}
	
	/**
	 * Property accessor.
	 * 
	 * @param string $name Name of the property to return.
	 * 
	 * @since 0.2 - Nov 7, 2006
	 */
	public function __get($name)
	{
		return $this->properties->$name;
	}
	
	/**
	 * Property mutator.
	 * 
	 * @param string $name Name of the property to change.
	 * @param any $value Value to assign to the property.
	 * 
	 * @since 0.2 - Nov 7, 2006
	 */
	public function __set($name,$value)
	{
		$this->properties->$name = $value;
	}

	/**
	 * Render the button as HTML.
	 * 
	 * Generates the HTML needed to display the button on a form.
	 * Assumes the button will be span 2 columns in a table.
	 */
	public function display($formStyle)
	{
?>
<input type="submit" name="<?php echo $this->name; ?>" value="<?php echo $this->label; ?>"<?php $this->onClick(); ?> />
<?php
	}
	
	protected function onClick()
	{
  		if ($this->onClick) {
  			echo " onclick='".$this->onClick."'";
	  	}
	}
}

?>
