<?php
/**
 * Defines the CompareFieldsValidator class.
 * 
 * Created on Nov 6, 2006
 * Created by Randy
 * 
 * @package FormLib
 */
  
/**
 * This validator can compare the values of 2 fields.  The values can be
 * compare using the standard comparison operators (<, <=, ==, !=, etc...)
 * 
 * @package FormLib
 * @version 0.2
 * @author Randy
 */

class CompareFieldsValidator extends Validator
{
	private $fieldToCompare;
	private $operation;
	
	/**
	 * Constructor for CompareFieldsValidator objects.
	 * 
	 * @param Field $fieldToCompare Reference to the other field to be compared.
	 * @param string $operation The type of comparision to perform.  Must be one
	 * of: <ul><li>< <li><= <li>== <li>!= <li>>= <li>> </ul>
	 */
	public function __construct($fieldToCompare, $operation = "==")
	{
		if(  $fieldToCompare instanceof Field )
		{
			$this->fieldToCompare = $fieldToCompare;
			switch($operation)
			{
				case "<":
				case "<=":
				case "==":
				case "!=":
				case ">=":
				case ">";
					$this->operation = $operation;
					break;
				default:
					throw new Exception("CompareFieldsValidator error: unsupported operation '$operation'");
			}
		} else {
			throw new Exception("CompareFieldsValidator error: fieldToCompare must be of type Field");
		}
	}
	
	public function isValid(&$field)
	{
		switch($this->operation)
		{
			case "<":
				return $field->value < $this->fieldToCompare->value;
			case "<=":
				return $field->value <= $this->fieldToCompare->value;
			case "==":
				return $field->value == $this->fieldToCompare->value;
			case "!=":
				return $field->value != $this->fieldToCompare->value;
			case ">=":
				return $field->value >= $this->fieldToCompare->value;
			case ">":
				return $field->value > $this->fieldToCompare->value;
		}
		// Should never get here
		throw new Exception("CompareFieldsValidator::isValid error: operation '$this->operation' not supported");
	}
	
	public function errorMessage($field)
	{
		switch ($this->operation)
		{
			case "==":
				return $this->fieldToCompare->label." does not match ".$field->label;
			default:
				return $this->fieldToCompare->label." must be ".$this->operation." than ".$field->label;
		}
	}
}

?>
