<?php
/**
 * Defines the DefaultValueValidator class.
 * 
 * Created on Nov 6, 2006
 * Created by Randy
 * 
 * @package FormLib
 */
  
/**
 * Supplies a default field value if the user leaves the field empty.
 * 
 * @package FormLib
 * @version 0.2
 * @author Randy
 */

class DefaultValueValidator extends Validator
{
	/**
	 * This private member is used to store the default value.
	 */
	private $defaultValue;
	
	/**
	 * Initializes a DefaultValueValidator object.
	 * 
	 * @param any $defaultValue The field's default value.
	 */
	public function __construct($defaultValue)
	{
		$this->defaultValue = $defaultValue;
	}
	
	/**
	 * Checks the value the user entered and if empty/missing, sets the
	 * field with the default value supplied to the constructor.
	 */
	public function isValid(&$field)
	{
		if( !isset($field->value) || empty($field->value) )
			$field->value = $this->defaultValue;
		return true;	
	}
	
	/**
	 * This validator never generates an error.
	 */
	public function errorMessage($field)
	{
		return "";
	}
}

?>
