<?php
/**
 * Defines the EmailValidator class.
 * 
 * Created on Nov 6, 2006
 * Created by Randy
 * 
 * @package FormLib
 */
  
/**
 * Validates a field as an e-mail address using a regular expression.
 * 
 * @package FormLib
 * @version 0.2
 * @author Randy
 */

class EmailValidator extends RegexValidator
{
	public function __construct()
	{
		parent::__construct("^[^@]{1,64}@[^@]{1,255}$", "E-mail Address");
	}
	
	public function isValid(&$field)
	{
		// Does it pass the basic e-mail test?
		if( !parent::isValid($field) )
			return false;
			
		// Good.  So split address down in sections for additional analysis.
		$email_array = explode("@", $field->value);
		$local_array = explode(".", $email_array[0]);
		
		// Check the local parts (before the @) to make sure
		// it does not have bad characters and is between 1-62 long.
		for( $i = 0; $i < count($local_array); $i++) {
			if( !ereg("^(([A-Za-z0-9!#$%&'*+/=?^_`{|}~-][A-Za-z0-9!#$%&'*+/=?^_`{|}~\.-]{0,63})|(\"[^(\\|\")]{0,62}\"))$", $local_array[$i])) {
				return false;
			}
		}
		
		// Finally, analysis the domain part (after the @) and allow
		// either an IP address, or what appears to be a valid domain name.
		if (!ereg("^\[?[0-9\.]+\]?$", $email_array[1])) {
			$domain_array = explode(".", $email_array[1]);
			if (sizeof($domain_array) < 2) {
				return false; // Not enough parts
			}
			for ($i = 0; $i < sizeof($domain_array); $i++) {
				if (!ereg("^(([A-Za-z0-9][A-Za-z0-9-]{0,61}[A-Za-z0-9])|([A-Za-z0-9]+))$",  $domain_array[$i])) {
					return false;
				}
			}
		}
		
		// All checks were successful
		return true;
	}
}

?>
