<?php
/**
 * Defines the ImageButton class used on forms.
 * 
 * @package FormLib
 */
  
/**
 * An image button class with rollover effects.
 * 
 * When using the rollover effect, you must create 3 buttons to be used
 * in normal, hover and clicked modes.  The image file names must be
 * end with the following suffixes:
 * 
 * Normal Mode (*-up.*   or *1.*)
 * Hover Mode  (*-over.* or *2.*)
 * Click Mode: (*-down.* or *3.*)
 * 
 * @package FormLib
 * @version 0.1
 * @author Randy
 */

class ImageButton extends Button
{
	/**
	 * Constructor.
	 * 
	 * @param string $name The name assigned to the button.
	 * @param string $image URL of the image file.
	 * @param string $label The alt/title for the image (Section 508).
	 * @param boolean $rollover Flag to enable rollover effects.
	 * @param PropertyHolder $properties Extra properties to associate with the button.
	 * @param PropertyHolder $style Style settings for the button.
	 */
	public function __construct($name, $image, $label, $rollover = false, $style = false)
	{
		parent::__construct($name, $label, $style);
		$this->properties->add("image", $image);
		$this->properties->add("rollover", $rollover);
	}
	
	/**
	 * Displays the button in 2 columns of a table row.
	 * 
	 * @param PropertyHolder $formStyle The form's style settings. (Not used)
	 */
	public function display($formStyle)
	{
		echo "<tr><td colspan=\"2\" align=\"center\">";
		echo "<input type=\"image\" name=\"$this->name\" src=\"$this->image\" alt=\"";
		echo $this->label;
		echo "\" title=\"";
		echo $this->label;
		echo "\" value=\"";
		echo $this->label;
		echo "\"";
		$this->onClick();
		if( $this->rollover)
			$this->addRollover();
		echo "/></td></tr>"; 
		
	}

	/**
	 * Animates the image button.
	 * 
	 * Outputs the required JavaScript to change images using
	 * onMouseOut, onMouseOver and onMouseDown.
	 */
	protected function addRollover()
	{
		// Is the image named properly?
		$pos = strripos($this->image, "-up.");
		if( $pos ) {
			$overImage = substr($this->image, 0, $pos) . "-over" . substr($this->image, $pos+3);
			$downImage = substr($this->image, 0, $pos) . "-down" . substr($this->image, $pos+3);
		} else {
			$pos = strripos($this->image, "1.");
			if( $pos ) {
				$overImage = substr($this->image, 0, $pos) . "2" . substr($this->image, $pos+1);
				$downImage = substr($this->image, 0, $pos) . "3" . substr($this->image, $pos+1);
			} else {
				return;
			}
		}
			
		echo " onMouseOut=\"this.src='$this->image'\" onMouseOver=\"this.src='$overImage'\" onMouseDown=\"this.src='$downImage'\"";
	}
}

?>