<?php
/**
 * Defines the LinkImageButton class.
 * 
 * @package FormLib
 */
  
/**
 * This class is similar to the ImageButton class, but supports redirecting the
 * user to a URL when the button is clicked.
 * 
 * @package package_name
 * @version 0.1
 * @author Randy L. Pearson
 */

class LinkImageButton extends ImageButton
{
	/**
	 * Constructor.
	 * 
	 * @param string $name The name assigned to the button.
	 * @param string $image URL of the image file.
	 * @param string $label The alt/title for the image (Section 508).
	 * 
	 * @param boolean $rollover Flag to enable rollover effects.
	 * @param PropertyHolder $properties Extra properties to associate with the button.
	 * @param PropertyHolder $style Style settings for the button.
	 */
	public function __construct($name, $image, $label, $url, $rollover = false, $style = false)
	{
		parent::__construct($name, $image, $label, $rollover, $style);
		$this->onClick = 'location.href="'.s($url).'"';
	}
	
	/**
	 * Displays the button.  Does not expect to be inside a table.
	 * 
	 * @param PropertyHolder $formStyle The form's style settings. (Not used)
	 */
	public function display($formStyle)
	{
		echo "<input type=\"image\" name=\"$this->name\" src=\"$this->image\" alt=\"";
		echo $this->label;
		echo "\" title=\"";
		echo $this->label;
		echo "\" value=\"";
		echo $this->label;
		echo "\"";
		$this->onClick();
		if( $this->rollover)
			$this->addRollover();
		echo "/>"; 
	}
}

?>
