<?php
/**
 * Defines the PasswordField class.
 * 
 * @package FormLib
 */
 
/**
 * Object oriented wrapper around an HTML text password field.
 * 
 * This version replaces the custom render by passing the type of
 * field to the TextField constructor so its display() function
 * can use any available type value.
 * 
 * @package FormLib
 * @version 0.4
 * @author Randy L. Pearson
 */
 
class PasswordField extends TextField
{
	/**
	 * Constructor
	 * Initializes a PasswordField object.
	 * 
	 * @param string $name Name assigned to the field.
	 * @param string $label Text assigned to the field.
	 * @param string $value Value assigned to the field. (Default: "")
	 */
	 public function __construct($name, $label, $value = "")
	 {
	 	parent::__construct($name, $label, $value, 30, 20);
	 }

	/**
	 * Renders the field as HTML.
	 * 
	 * @param PropertyHolder $formStyle Form style settings.
	 */
	protected function displayField($formStyle)
	{
?>
  <input type="password" name="<?php echo $this->name; ?>" value="<?php echo $this->value; ?>" size="<?php echo $this->size; ?>" maxlength="<?php echo $this->maxLength; ?>" />
<?php
	}
	 
	 /**
	  * Runs the current password through an encryption engine.
	  * 
	  * @return string Encrypted form of the password.
	  */
	 public function encrypted(CryptEngine $encryptor = null)
	 {
	 	if (is_null($encryptor))
	 		$encryptor = CryptFactory::createEngine("CryptNativeMD5");
	 	return $encryptor->encrypt($this->value);
	 }
}

?>
