<?php
/**
 * Defines the TextField class.
 * 
 * @package FormLib
 */
 
/**
 * Object oriented wrapper around an HTML text input field.
 * 
 * @package FormLib
 * @version 0.3
 * @author Randy L. Pearson
 * 
 */
class TextField extends Field
{
	/**
	 * Constructor
	 * 
	 * Initializes a TextField object.
	 * 
	 * @param string $name Name assigned to the field.
	 * @param string $label Text assigned to the field.
	 * @param string $value Value assigned to the field.
	 * @param integer $maxLength Maximum number of characters the field will accept. (Default: 255)
	 * @param integer $size Width of the field on the HTML page.  (Default: 40)
	 */
	public function __construct($name, $label, $value = "", $maxLength = 255, $size = 40)
	{
		parent::__construct($name, $label, $value);
		$this->properties->add("maxLength", $maxLength);
		$this->properties->add("size", $size);
	}
	
	/**
	 * Renders the label and text field assuming a 2 column table.
	 * 
	 * @param PropertyHolder $formStyle Form style settings.
	 */
	protected function displayField($formStyle)
	{
?>
  <input type="text" name="<?php echo $this->name; ?>" value="<?php echo $this->value; ?>" size="<?php echo $this->size; ?>" maxlength="<?php echo $this->maxLength; ?>" />
<?php
	}
}

?>
