<?php
/**
 * Defines the abstract Validator class.
 * 
 * @package FormLib
 */
  
/**
 * The Validator class supports testing field values to make sure
 * the user enters properly formatted data. 
 * 
 * Version 0.2 revises the isValid() and errorMessage() functions to accept
 * the field being tested instead of the value in the field.  This allows
 * access to other field properties, such as the label for error messages.
 * 
 * @package FormLib
 * @version 0.2
 * @author Randy
 */

abstract class Validator
{
	/**
	 * Validates the value the user entered into a field.
	 * 
	 * @param Field &$field A reference to the Field object.
	 * @return boolean <b>true</b> if data is valid, <b>false</b> if not.
	 */
	abstract public function isValid(&$field);
	
	/**
	 * Get an error message that can be shown to the user.
	 * 
	 * @param Field $field The field object.
	 * @return string The error message.
	 */
	abstract public function errorMessage($field);
}

?>
