<?php
/**
 * Defines the PropertyHolder interface.
 * 
 * @package SupportLib
 */
 
/**
 * Defines a generic interface for objects that can manage name/value
 * property pairs.  Different holders can be defined that use either
 * memory, databases, files or even network storage and swapped in
 * as needed.
 * 
 * @package SupportLib
 * @version 0.2
 * @author Randy L. Pearson
 */
interface PropertyHolder
{
	/**
	 * Adds a new property to the bag.
	 * 
	 * @param string $name Name of the new property.
	 * @param string $value Value of the property.  (Default: "")
	 */
	public function add($name,$value = "");

	/**
	 * Returns a list of valid property names.
	 * 
	 * @return array An array of the current property names as strings.
	 */
	public function names();
	
	/**
	 * Tests to see if a property name is valid.
	 * 
	 * @param string $name The property name.
	 * @return boolean true/false
	 * 
	 * @since 0.2 - Nov 6, 2006
	 */
	public function isValidName($name);
}

?>
