<?php
/*
 * Created on Sep 12, 2006
 *
 * common.php -- Setup sessions, connects to database, etc...
 */

/**
 * Support code for projects using the CryptLib, FormLib and SupportLib packages
 * developed by Randy Pearson during PHP training at the University of Alabama
 * in Huntsville.
 * 
 * @author Randy L. Pearson
 * @link http://www.coned.uah.edu Continuing Education Division Web Site
 * @link http://www.bamafolks.com/~randy/ Randy's Personal Home Page
 */

/**
 * Add library directories to the AUTOLOAD_PATH.
 */
if (!isset($AUTOLOAD_PATH))
	$AUTOLOAD_PATH = "$CFG->includedir";
else
	$AUTOLOAD_PATH .= PATH_SEPARATOR . "$CFG->includedir";
$AUTOLOAD_PATH .= PATH_SEPARATOR . "$CFG->includedir/SupportLib";
$AUTOLOAD_PATH .= PATH_SEPARATOR . "$CFG->includedir/FormLib";
$AUTOLOAD_PATH .= PATH_SEPARATOR . "$CFG->includedir/CryptLib";

/**
 * A global __autoload that automatically loads classes.
 * 
 * When called it searches a list of directories defined by a global
 * AUTOLOAD_PATH variable.  The list should use the native system path
 * separator character (i.e. ';' for Windows, ':' for Linux, etc.)
 * 
 * @return nothing Throws an error if the class cannot be loaded.
 */
function __autoload($class)
{
	global $CFG, $AUTOLOAD_PATH;
	
	if( isset($AUTOLOAD_PATH) ) {
		$paths = explode(PATH_SEPARATOR, $AUTOLOAD_PATH);
		foreach( $paths as $path ) {
			if( file_exists("$path/$class.php")) {
				require_once "$path/$class.php";
				return;
			}
		}
	} else {
		if( file_exists("$CFG->includedir/$class.php") ) {
			require_once "$CFG->includedir/$class.php";
			return;
		}
	}
	
	throw new Exception("__autoload failed: $class.php not found");
}

// Attempt to connect to the database.
error_reporting(0);
if ($CFG->db_persistent) {
	$db_options = array(PDO::ATTR_PERSISENT => true);
} else {
	$db_options = array();
}
try {
	$db = new PDO($CFG->dsn, $CFG->db_user, $CFG->db_pass, $db_options);
} catch (PDOException $e) {
	die("Connection failed: " . $e->getMessage());
}

/**
 * Set the PDO error mode to raise exceptions on errors.
 */
if (isset($CFG->debug) && $CFG->debug > 7) {
	$db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
}

// Load additional support libraries
error_reporting(E_ALL);
require_once "$CFG->includedir/datalib.php";

// Return error reporting to normal level
if(!isset($CFG->debug))
	$CFG->debug = 0;
error_reporting($CFG->debug);

if (!isset($CFG->sessioncookie)) {
	$CFG->sessioncookie = '';
}

/**
 * Function to read a boolean value from the PHP.INI file.
 * 
 * Converts the following strings to <i>true</i>:  <b>1</b>, <b>on</b>,
 * <b>true</b>, and <b>yes</b>. All other values will be treated as
 * <i>false</i>.
 * 
 * @param string $setting The desired PHP.INI setting to read.
 * @return boolean The value of the setting.
 */
function ini_get_bool($setting)
{
	$temp = ini_get($setting);
	
	if ($temp == '1' or strtolower($temp) == "on" or strtolower($temp) == "true" or strtolower($temp) == "yes")
		return true;
	return false;
}

/**
 * A version of addslashes that can recursively process arrays.
 * 
 * @param any &$array A reference to an array or simple variable.
 * 
 * @see addslashes()
 */
function my_addslashes(&$array)
{
	foreach ($array as $key => $var) {
		if (!is_array($var))
			$array[$key] = addslashes($var);
		else {
			foreach ($var as $arrkey => $arrvar)
				$var[$arrkey] = addslashes($arrvar);
			$array[$key] = $var;
		}
	}
}

/**
 *  Hack to work around disabled magic_quotes_gpc in PHP.INI.
 */
if (!ini_get_bool("magic_quotes_gpc")) {
	my_addslashes($_GET);
	my_addslashes($_POST);
	my_addslashes($_COOKIE);
}

/**
 * This is a very simple PHP class that can be used to hold data.
 */
class object {};

/**
 * Define our session cookie name, unless disabled.
 */
if (!isset($CFG->nocookies)) {
	session_name("MyTunes".$CFG->sessioncookie);
}

/**
 * Start a new session for tracking user information/preferences.
 */
@session_start();
if (!isset($_SESSION['SESSION']))
	$_SESSION['SESSION'] = new object;
		
/**
 *  Setup global variables for easy access to SESSION and USER
 */
$SESSION   =& $_SESSION['SESSION'];
$USER      =& $_SESSION['USER'];
	
// In rare cases (PHP 4.1.2 as CGI under Windows/IIS) you may need the following:
// session_register("USER");
// session_register("SESSION");

/**
 * Checks to see if the user is logged in.  If not, redirects to
 * the login page.
 * 
 * @see is_logged_in()
 * @see logout_user()
 */
function require_login()
{
	global $CFG;
	
	if(!is_logged_in())
	{	
		redirect("$CFG->wwwroot/login.php");
		die;
	}
}

/**
 * Checks to see if the user is currently logged in.
 * 
 * Uses the global $USER variable, which must have an id property.  This
 * global variable should be tied to a session variable by the same name.
 * 
 * @return boolean True if
 * 
 * @see require_login()
 * @see logout_user()
 */
function is_logged_in()
{
	global $USER;
	return isset($USER) && isset($USER->id);
}

/**
 * Logs a user out by clearing the user's session.
 * 
 * @see is_logged_in()
 * @see require_login()
 */
function logout_user()
{
	session_unset();
	session_destroy();
	$_SESSION = array();
}

// Again, it is important that the following line does not
// have any extra spaces or new lines after it.
?>